@@ -34,7 +34,7 @@ mainwindow::mainwindow(QWidget *parent) :
     orientationChanged();
     readvalues();
     abouttext = tr("Author: d-iivil<br />Licence: GPL");
-    abouttitle = "CSSU Transitions Tuner " + tr("version") + " 0.1.3";
+    abouttitle = "CSSU Transitions Tuner " + tr("version") + " 0.1.4";
 }
 
 mainwindow::~mainwindow()
@@ -118,15 +118,26 @@ void mainwindow::readvalues()
         }
 
 
+     settings.endGroup();
+
+     settings.beginGroup("launcher");
+
+     if (settings.contains("deceleration_rate")) {
+     QString deceleration_rate = settings.value("deceleration_rate").toString();
+     double deceleration_ratesouble = deceleration_rate.replace('.', ',').toDouble();
+     ui->scrollrate->setValue(deceleration_ratesouble);
+     }
+
+
      settings.endGroup();
 
      settings.beginGroup("launcher_in");
      int speed = settings.value("duration").toInt();
-     if (speed <= 50) {
+     if (speed <= 100) {
          ui->speed->setCurrentIndex(0);
-     } else if (speed >= 51 && speed <= 100) {
+     } else if (speed >= 101 && speed <= 200) {
          ui->speed->setCurrentIndex(1);
-     } else if (speed >= 101 && speed <= 300) {
+     } else if (speed >= 201 && speed <= 300) {
          ui->speed->setCurrentIndex(2);
      } else if (speed >= 301 && speed <= 400) {
          ui->speed->setCurrentIndex(3);
@@ -146,20 +157,20 @@ void mainwindow::storevalues()
     path2 = "/etc/hildon/theme/transitions.ini";
     system("perl -pi -e \"s/#/;/g\" /etc/hildon/theme/transitions.ini");
 
-    if (ui->speed->currentIndex() == 0) system("perl -pi -e \"s/duration=.*/duration=50/g\" /etc/hildon/theme/transitions.ini");
-    if (ui->speed->currentIndex() == 1) system("perl -pi -e \"s/duration=.*/duration=100/g\" /etc/hildon/theme/transitions.ini");
+    if (ui->speed->currentIndex() == 0) system("perl -pi -e \"s/duration=.*/duration=100/g\" /etc/hildon/theme/transitions.ini");
+    if (ui->speed->currentIndex() == 1) system("perl -pi -e \"s/duration=.*/duration=150/g\" /etc/hildon/theme/transitions.ini");
     if (ui->speed->currentIndex() == 2) system("perl -pi -e \"s/duration=.*/duration=300/g\" /etc/hildon/theme/transitions.ini");
     if (ui->speed->currentIndex() == 3) system("perl -pi -e \"s/duration=.*/duration=400/g\" /etc/hildon/theme/transitions.ini");
     if (ui->speed->currentIndex() == 4) system("perl -pi -e \"s/duration=.*/duration=500/g\" /etc/hildon/theme/transitions.ini");
 
-    if (ui->speed->currentIndex() == 0) system("perl -pi -e \"s/duration_in=.*/duration_in=50/g\" /etc/hildon/theme/transitions.ini");
-    if (ui->speed->currentIndex() == 1) system("perl -pi -e \"s/duration_in=.*/duration_in=100/g\" /etc/hildon/theme/transitions.ini");
+    if (ui->speed->currentIndex() == 0) system("perl -pi -e \"s/duration_in=.*/duration_in=100/g\" /etc/hildon/theme/transitions.ini");
+    if (ui->speed->currentIndex() == 1) system("perl -pi -e \"s/duration_in=.*/duration_in=150/g\" /etc/hildon/theme/transitions.ini");
     if (ui->speed->currentIndex() == 2) system("perl -pi -e \"s/duration_in=.*/duration_in=300/g\" /etc/hildon/theme/transitions.ini");
     if (ui->speed->currentIndex() == 3) system("perl -pi -e \"s/duration_in=.*/duration_in=400/g\" /etc/hildon/theme/transitions.ini");
     if (ui->speed->currentIndex() == 4) system("perl -pi -e \"s/duration_in=.*/duration_in=500/g\" /etc/hildon/theme/transitions.ini");
 
-    if (ui->speed->currentIndex() == 0) system("perl -pi -e \"s/duration_out=.*/duration_out=50/g\" /etc/hildon/theme/transitions.ini");
-    if (ui->speed->currentIndex() == 1) system("perl -pi -e \"s/duration_out=.*/duration_out=100/g\" /etc/hildon/theme/transitions.ini");
+    if (ui->speed->currentIndex() == 0) system("perl -pi -e \"s/duration_out=.*/duration_out=100/g\" /etc/hildon/theme/transitions.ini");
+    if (ui->speed->currentIndex() == 1) system("perl -pi -e \"s/duration_out=.*/duration_out=150/g\" /etc/hildon/theme/transitions.ini");
     if (ui->speed->currentIndex() == 2) system("perl -pi -e \"s/duration_out=.*/duration_out=300/g\" /etc/hildon/theme/transitions.ini");
     if (ui->speed->currentIndex() == 3) system("perl -pi -e \"s/duration_out=.*/duration_out=400/g\" /etc/hildon/theme/transitions.ini");
     if (ui->speed->currentIndex() == 4) system("perl -pi -e \"s/duration_out=.*/duration_out=500/g\" /etc/hildon/theme/transitions.ini");
@@ -168,20 +179,20 @@ void mainwindow::storevalues()
 
     QString path = "/usr/share/hildon-desktop/transitions.ini";
     system("perl -pi -e \"s/#/;/g\" /usr/share/hildon-desktop/transitions.ini");
-    if (ui->speed->currentIndex() == 0) system("perl -pi -e \"s/duration=.*/duration=50/g\" /usr/share/hildon-desktop/transitions.ini");
-    if (ui->speed->currentIndex() == 1) system("perl -pi -e \"s/duration=.*/duration=100/g\" /usr/share/hildon-desktop/transitions.ini");
+    if (ui->speed->currentIndex() == 0) system("perl -pi -e \"s/duration=.*/duration=100/g\" /usr/share/hildon-desktop/transitions.ini");
+    if (ui->speed->currentIndex() == 1) system("perl -pi -e \"s/duration=.*/duration=150/g\" /usr/share/hildon-desktop/transitions.ini");
     if (ui->speed->currentIndex() == 2) system("perl -pi -e \"s/duration=.*/duration=300/g\" /usr/share/hildon-desktop/transitions.ini");
     if (ui->speed->currentIndex() == 3) system("perl -pi -e \"s/duration=.*/duration=400/g\" /usr/share/hildon-desktop/transitions.ini");
     if (ui->speed->currentIndex() == 4) system("perl -pi -e \"s/duration=.*/duration=500/g\" /usr/share/hildon-desktop/transitions.ini");
 
-    if (ui->speed->currentIndex() == 0) system("perl -pi -e \"s/duration_in=.*/duration_in=50/g\" /usr/share/hildon-desktop/transitions.ini");
-    if (ui->speed->currentIndex() == 1) system("perl -pi -e \"s/duration_in=.*/duration_in=100/g\" /usr/share/hildon-desktop/transitions.ini");
+    if (ui->speed->currentIndex() == 0) system("perl -pi -e \"s/duration_in=.*/duration_in=100/g\" /usr/share/hildon-desktop/transitions.ini");
+    if (ui->speed->currentIndex() == 1) system("perl -pi -e \"s/duration_in=.*/duration_in=150/g\" /usr/share/hildon-desktop/transitions.ini");
     if (ui->speed->currentIndex() == 2) system("perl -pi -e \"s/duration_in=.*/duration_in=300/g\" /usr/share/hildon-desktop/transitions.ini");
     if (ui->speed->currentIndex() == 3) system("perl -pi -e \"s/duration_in=.*/duration_in=400/g\" /usr/share/hildon-desktop/transitions.ini");
     if (ui->speed->currentIndex() == 4) system("perl -pi -e \"s/duration_in=.*/duration_in=500/g\" /usr/share/hildon-desktop/transitions.ini");
 
-    if (ui->speed->currentIndex() == 0) system("perl -pi -e \"s/duration_out=.*/duration_out=50/g\" /usr/share/hildon-desktop/transitions.ini");
-    if (ui->speed->currentIndex() == 1) system("perl -pi -e \"s/duration_out=.*/duration_out=100/g\" /usr/share/hildon-desktop/transitions.ini");
+    if (ui->speed->currentIndex() == 0) system("perl -pi -e \"s/duration_out=.*/duration_out=100/g\" /usr/share/hildon-desktop/transitions.ini");
+    if (ui->speed->currentIndex() == 1) system("perl -pi -e \"s/duration_out=.*/duration_out=150/g\" /usr/share/hildon-desktop/transitions.ini");
     if (ui->speed->currentIndex() == 2) system("perl -pi -e \"s/duration_out=.*/duration_out=300/g\" /usr/share/hildon-desktop/transitions.ini");
     if (ui->speed->currentIndex() == 3) system("perl -pi -e \"s/duration_out=.*/duration_out=400/g\" /usr/share/hildon-desktop/transitions.ini");
     if (ui->speed->currentIndex() == 4) system("perl -pi -e \"s/duration_out=.*/duration_out=500/g\" /usr/share/hildon-desktop/transitions.ini");
@@ -190,20 +201,20 @@ void mainwindow::storevalues()
     if (QFile::exists("/opt/theme-customizer/transitions.ini")) {
     path3 = "/opt/theme-customizer/transitions.ini";
     system("perl -pi -e \"s/#/;/g\" /opt/theme-customizer/transitions.ini");
-    if (ui->speed->currentIndex() == 0) system("perl -pi -e \"s/duration=.*/duration=50/g\" /opt/theme-customizer/transitions.ini");
-    if (ui->speed->currentIndex() == 1) system("perl -pi -e \"s/duration=.*/duration=100/g\" /opt/theme-customizer/transitions.ini");
+    if (ui->speed->currentIndex() == 0) system("perl -pi -e \"s/duration=.*/duration=100/g\" /opt/theme-customizer/transitions.ini");
+    if (ui->speed->currentIndex() == 1) system("perl -pi -e \"s/duration=.*/duration=150/g\" /opt/theme-customizer/transitions.ini");
     if (ui->speed->currentIndex() == 2) system("perl -pi -e \"s/duration=.*/duration=300/g\" /opt/theme-customizer/transitions.ini");
     if (ui->speed->currentIndex() == 3) system("perl -pi -e \"s/duration=.*/duration=400/g\" /opt/theme-customizer/transitions.ini");
     if (ui->speed->currentIndex() == 4) system("perl -pi -e \"s/duration=.*/duration=500/g\" /opt/theme-customizer/transitions.ini");
 
-    if (ui->speed->currentIndex() == 0) system("perl -pi -e \"s/duration_in=.*/duration_in=50/g\" /opt/theme-customizer/transitions.ini");
-    if (ui->speed->currentIndex() == 1) system("perl -pi -e \"s/duration_in=.*/duration_in=100/g\" /opt/theme-customizer/transitions.ini");
+    if (ui->speed->currentIndex() == 0) system("perl -pi -e \"s/duration_in=.*/duration_in=100/g\" /opt/theme-customizer/transitions.ini");
+    if (ui->speed->currentIndex() == 1) system("perl -pi -e \"s/duration_in=.*/duration_in=150/g\" /opt/theme-customizer/transitions.ini");
     if (ui->speed->currentIndex() == 2) system("perl -pi -e \"s/duration_in=.*/duration_in=300/g\" /opt/theme-customizer/transitions.ini");
     if (ui->speed->currentIndex() == 3) system("perl -pi -e \"s/duration_in=.*/duration_in=400/g\" /opt/theme-customizer/transitions.ini");
     if (ui->speed->currentIndex() == 4) system("perl -pi -e \"s/duration_in=.*/duration_in=500/g\" /opt/theme-customizer/transitions.ini");
 
-    if (ui->speed->currentIndex() == 0) system("perl -pi -e \"s/duration_out=.*/duration_out=50/g\" /opt/theme-customizer/transitions.ini");
-    if (ui->speed->currentIndex() == 1) system("perl -pi -e \"s/duration_out=.*/duration_out=100/g\" /opt/theme-customizer/transitions.ini");
+    if (ui->speed->currentIndex() == 0) system("perl -pi -e \"s/duration_out=.*/duration_out=100/g\" /opt/theme-customizer/transitions.ini");
+    if (ui->speed->currentIndex() == 1) system("perl -pi -e \"s/duration_out=.*/duration_out=150/g\" /opt/theme-customizer/transitions.ini");
     if (ui->speed->currentIndex() == 2) system("perl -pi -e \"s/duration_out=.*/duration_out=300/g\" /opt/theme-customizer/transitions.ini");
     if (ui->speed->currentIndex() == 3) system("perl -pi -e \"s/duration_out=.*/duration_out=400/g\" /opt/theme-customizer/transitions.ini");
     if (ui->speed->currentIndex() == 4) system("perl -pi -e \"s/duration_out=.*/duration_out=500/g\" /opt/theme-customizer/transitions.ini");
@@ -214,6 +225,8 @@ void mainwindow::storevalues()
     QSettings settings3(path3, QSettings::IniFormat);
 
     double parallaxint = ui->parallax->value();
+    double deceleration_rateint = ui->scrollrate->value();
+
     double ylaraja = 1;
     double alaraja = -1;
     if (parallaxint <= ylaraja && parallaxint >= 0) {
@@ -224,193 +237,164 @@ void mainwindow::storevalues()
     QString parallax = QString::number(parallaxint);
     parallax.replace(',', '.');
 
+    QString deceleration_rate = QString::number(deceleration_rateint);
+    deceleration_rate.replace(',', '.');
+
     int radius_moreint = ui->blur->value();
     QString radius_more = QString::number(radius_moreint);
 
     settings.beginGroup("thp_tweaks");
 
-  //  if (settings.contains("blurless")) {
         if ( ui->blurless->checkState() == Qt::Checked ) {
             settings.setValue("blurless","1");
         } else {
             settings.setValue("blurless","0");
         }
-   // }
 
-  //  if (settings.contains("taskswitcher")) {
         settings.setValue("taskswitcher", ui->taskswitcher->currentIndex());
-  //  }
 
-//    if (settings.contains("zaxisrotation")) {
         if ( ui->zaxis->checkState() == Qt::Checked ) {
             settings.setValue("zaxisrotation", "1");
         } else {
             settings.setValue("zaxisrotation", "0");
         }
-//    }
 
-//    if (settings.contains("tactilepopups")) {
         if ( ui->tactile->checkState() == Qt::Checked ) {
             settings.setValue("tactilepopups", "1");
         } else {
             settings.setValue("tactilepopups", "0");
         }
-//    }
 
-//    if (settings.contains("forcerotation")) {
         if ( ui->forcerotation->checkState() == Qt::Checked ) {
             settings.setValue("forcerotation", "1");
         } else {
             settings.setValue("forcerotation", "0");
         }
-//    }
 
 
      settings.endGroup();
 
      settings.beginGroup("home");
 
-  //   if (settings.contains("zoom_on_press")) {
         if ( ui->zoomonpress->checkState() == Qt::Checked ) {
             settings.setValue("zoom_on_press", "1");
         } else {
             settings.setValue("zoom_on_press", "0");
         }
-  //   }
 
-  //   if (settings.contains("parallax")) {
         settings.setValue("parallax", parallax);
- //   }
 
- //    if (settings.contains("radius_more")) {
         settings.setValue("radius_more", radius_more);
- //   }
+
+     settings.endGroup();
+
+     settings.beginGroup("launcher");
+
+     settings.setValue("deceleration_rate", deceleration_rate);
 
      settings.endGroup();
 
      settings2.beginGroup("thp_tweaks");
 
-  //   if (settings2.contains("blurless")) {
          if ( ui->blurless->checkState() == Qt::Checked ) {
              settings2.setValue("blurless","1");
          } else {
              settings2.setValue("blurless","0");
          }
-  //   }
 
- //    if (settings2.contains("taskswitcher")) {
          settings2.setValue("taskswitcher", ui->taskswitcher->currentIndex());
- //    }
 
- //    if (settings2.contains("zaxisrotation")) {
          if ( ui->zaxis->checkState() == Qt::Checked ) {
              settings2.setValue("zaxisrotation", "1");
          } else {
              settings2.setValue("zaxisrotation", "0");
          }
- //    }
 
- //    if (settings2.contains("forcerotation")) {
          if ( ui->forcerotation->checkState() == Qt::Checked ) {
              settings2.setValue("forcerotation", "1");
          } else {
              settings2.setValue("forcerotation", "0");
          }
-  //   }
 
-//     if (settings2.contains("tactilepopups")) {
          if ( ui->tactile->checkState() == Qt::Checked ) {
              settings2.setValue("tactilepopups", "1");
          } else {
              settings2.setValue("tactilepopups", "0");
          }
-//     }
 
 
       settings2.endGroup();
 
       settings2.beginGroup("home");
 
-  //    if (settings2.contains("zoom_on_press")) {
          if ( ui->zoomonpress->checkState() == Qt::Checked ) {
              settings2.setValue("zoom_on_press", "1");
          } else {
              settings2.setValue("zoom_on_press", "0");
          }
- //     }
 
 
-   //      double parallaxdouble = ui->parallax->value();
-   //   if (settings2.contains("parallax")) {
          settings2.setValue("parallax", parallax);
-  //   }
 
- //     if (settings2.contains("radius_more")) {
          settings2.setValue("radius_more", radius_more);
-  //   }
+
+      settings2.endGroup();
+
+      settings2.beginGroup("launcher");
+
+      settings2.setValue("deceleration_rate", deceleration_rate);
 
       settings2.endGroup();
 
       settings3.beginGroup("thp_tweaks");
 
-  //    if (settings3.contains("blurless")) {
           if ( ui->blurless->checkState() == Qt::Checked ) {
               settings3.setValue("blurless","1");
           } else {
               settings3.setValue("blurless","0");
           }
-  //    }
 
-  //    if (settings3.contains("taskswitcher")) {
           settings3.setValue("taskswitcher", ui->taskswitcher->currentIndex());
-  //    }
 
- //     if (settings3.contains("zaxisrotation")) {
           if ( ui->zaxis->checkState() == Qt::Checked ) {
               settings3.setValue("zaxisrotation", "1");
           } else {
               settings3.setValue("zaxisrotation", "0");
           }
-  //    }
 
-  //    if (settings3.contains("forcerotation")) {
           if ( ui->forcerotation->checkState() == Qt::Checked ) {
               settings3.setValue("forcerotation", "1");
           } else {
               settings3.setValue("forcerotation", "0");
           }
-  //    }
 
- //     if (settings3.contains("tactilepopups")) {
           if ( ui->tactile->checkState() == Qt::Checked ) {
               settings3.setValue("tactilepopups", "1");
           } else {
               settings3.setValue("tactilepopups", "0");
           }
-  //    }
 
 
        settings3.endGroup();
 
        settings3.beginGroup("home");
 
-  //     if (settings3.contains("zoom_on_press")) {
           if ( ui->zoomonpress->checkState() == Qt::Checked ) {
               settings3.setValue("zoom_on_press", "1");
           } else {
               settings3.setValue("zoom_on_press", "0");
           }
-  //     }
 
 
-    //      double parallaxdouble = ui->parallax->value();
-   //    if (settings3.contains("parallax")) {
           settings3.setValue("parallax", parallax);
-   //   }
 
-   //    if (settings3.contains("radius_more")) {
           settings3.setValue("radius_more", radius_more);
-   //   }
+
+       settings3.endGroup();
+
+       settings3.beginGroup("launcher");
+
+       settings3.setValue("deceleration_rate", deceleration_rate);
 
        settings3.endGroup();
 
